@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "createnewnotejob.h"
 #include "notesharedglobalconfig.h"
@@ -51,7 +38,7 @@ public:
     QString mTitle;
     QString mText;
     bool mRichText = false;
-    QWidget *mWidget = nullptr;
+    QWidget *const mWidget;
 };
 
 CreateNewNoteJob::CreateNewNoteJob(QObject *parent, QWidget *widget)
@@ -113,7 +100,7 @@ void CreateNewNoteJob::createFetchCollectionJob(bool useSettings)
         col = Akonadi::Collection(id);
     }
     NoteShared::NoteSharedGlobalConfig::self()->save();
-    Akonadi::CollectionFetchJob *fetchCollection = new Akonadi::CollectionFetchJob(col, Akonadi::CollectionFetchJob::Base);
+    auto *fetchCollection = new Akonadi::CollectionFetchJob(col, Akonadi::CollectionFetchJob::Base);
     connect(fetchCollection, &Akonadi::CollectionFetchJob::result, this, &CreateNewNoteJob::slotFetchCollection);
 }
 
@@ -128,7 +115,7 @@ void CreateNewNoteJob::slotFetchCollection(KJob *job)
         }
         return;
     }
-    Akonadi::CollectionFetchJob *fetchCollection = qobject_cast<Akonadi::CollectionFetchJob *>(job);
+    auto *fetchCollection = qobject_cast<Akonadi::CollectionFetchJob *>(job);
     if (fetchCollection->collections().isEmpty()) {
         qCDebug(NOTESHARED_LOG) << "No collection fetched";
         if (KMessageBox::Yes == KMessageBox::warningYesNo(nullptr, i18n("An error occurred during fetching. Do you want to select a new default collection?"))) {
@@ -143,7 +130,7 @@ void CreateNewNoteJob::slotFetchCollection(KJob *job)
         if (!col.hasAttribute<NoteShared::ShowFolderNotesAttribute>()) {
             if (KMessageBox::Yes == KMessageBox::warningYesNo(nullptr, i18n("Collection is hidden. New note will be stored but not displayed. Do you want to show collection?"))) {
                 col.addAttribute(new NoteShared::ShowFolderNotesAttribute());
-                Akonadi::CollectionModifyJob *job = new Akonadi::CollectionModifyJob(col);
+                auto *job = new Akonadi::CollectionModifyJob(col);
                 connect(job, &Akonadi::CollectionModifyJob::result, this, &CreateNewNoteJob::slotCollectionModifyFinished);
             }
         }
@@ -177,12 +164,12 @@ void CreateNewNoteJob::slotFetchCollection(KJob *job)
 
         newItem.setPayload(newPage);
 
-        Akonadi::EntityDisplayAttribute *eda = new Akonadi::EntityDisplayAttribute();
+        auto *eda = new Akonadi::EntityDisplayAttribute();
 
         eda->setIconName(QStringLiteral("text-plain"));
         newItem.addAttribute(eda);
 
-        Akonadi::ItemCreateJob *job = new Akonadi::ItemCreateJob(newItem, col, this);
+        auto *job = new Akonadi::ItemCreateJob(newItem, col, this);
         connect(job, &Akonadi::ItemCreateJob::result, this, &CreateNewNoteJob::slotNoteCreationFinished);
     } else {
         deleteLater();
