@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "knotesiconview.h"
@@ -59,7 +46,7 @@ bool KNotesIconView::event(QEvent *e)
     if (e->type() != QEvent::ToolTip) {
         return QListWidget::event(e);
     }
-    QHelpEvent *he = static_cast< QHelpEvent * >(e);
+    auto *he = static_cast< QHelpEvent * >(e);
 
     QPoint pnt = viewport()->mapFromGlobal(mapToGlobal(he->pos()));
 
@@ -69,7 +56,7 @@ bool KNotesIconView::event(QEvent *e)
 
     QListWidgetItem *item = itemAt(pnt);
     if (item) {
-        KNotesIconViewItem *noteItem = static_cast<KNotesIconViewItem *>(item);
+        auto *noteItem = static_cast<KNotesIconViewItem *>(item);
         NoteShared::NoteUtils noteUtils;
         const QString toolTip = noteUtils.createToolTip(noteItem->item());
         QToolTip::showText(he->globalPos(), toolTip, viewport(), visualItemRect(item));
@@ -89,7 +76,7 @@ void KNotesIconView::mousePressEvent(QMouseEvent *e)
 
 void KNotesIconView::addNote(const Akonadi::Item &item)
 {
-    KNotesIconViewItem *iconView = new KNotesIconViewItem(item, this);
+    auto *iconView = new KNotesIconViewItem(item, this);
     mNoteList.insert(item.id(), iconView);
 }
 
@@ -155,7 +142,7 @@ void KNotesIconViewItem::setReadOnly(bool b, bool save)
         }
     }
     if (save) {
-        Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+        auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_KONTACT_PLUGIN_LOG) << " KNotesIconViewItem::setReadOnly savenote";
 #endif
@@ -166,7 +153,7 @@ void KNotesIconViewItem::setReadOnly(bool b, bool save)
 void KNotesIconViewItem::setDisplayDefaultValue()
 {
     KNoteUtils::setDefaultValue(mItem);
-    Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+    auto *job = new Akonadi::ItemModifyJob(mItem);
     connect(job, &Akonadi::ItemModifyJob::result, this, &KNotesIconViewItem::slotNoteSaved);
 }
 
@@ -286,7 +273,7 @@ void KNotesIconViewItem::saveNoteContent(const QString &subject, const QString &
     }
 
     if (position >= 0) {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-Cursor-Position");
+        auto *header = new KMime::Headers::Generic("X-Cursor-Position");
         header->fromUnicodeString(QString::number(position), "utf-8");
         message->setHeader(header);
     }
@@ -294,7 +281,7 @@ void KNotesIconViewItem::saveNoteContent(const QString &subject, const QString &
     message->assemble();
 
     mItem.setPayload(message);
-    Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+    auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
     qCDebug(KNOTES_KONTACT_PLUGIN_LOG) << " KNotesIconViewItem::saveNoteContent savenote";
 #endif
