@@ -1,25 +1,11 @@
 /*******************************************************************
  KNotes -- Notes for the KDE project
 
- Copyright (c) 1997-2013, The KNotes Developers
+ SPDX-FileCopyrightText: 1997-2013 The KNotes Developers
 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ SPDX-License-Identifier: GPL-2.0-or-later
 *******************************************************************/
 
-#include <config-knotes.h>
-
 #include "knote.h"
 #include "knotes_debug.h"
 #include "knotedisplaysettings.h"
@@ -66,9 +52,9 @@
 #include <QSizeGrip>
 #include <QVBoxLayout>
 #include <QTextEdit>
-#include <KWindowSystem/NETWM>
 
 #if KDEPIM_HAVE_X11
+#include <KWindowSystem/NETWM>
 #include <fixx11h.h>
 #endif
 
@@ -77,11 +63,6 @@
 KNote::KNote(const QDomDocument &buildDoc, const Akonadi::Item &item, bool allowAkonadiSearchDebug, QWidget *parent)
     : QFrame(parent, Qt::FramelessWindowHint)
     , mItem(item)
-    , m_label(nullptr)
-    , m_grip(nullptr)
-    , m_button(nullptr)
-    , m_tool(nullptr)
-    , m_editor(nullptr)
     , m_kwinConf(KSharedConfig::openConfig(QStringLiteral("kwinrc")))
     , mDisplayAttribute(new KNoteDisplaySettings)
     , mAllowDebugAkonadiSearch(allowAkonadiSearchDebug)
@@ -114,7 +95,7 @@ KNote::~KNote()
 void KNote::setDisplayDefaultValue()
 {
     KNoteUtils::setDefaultValue(mItem);
-    Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+    auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
     qCDebug(KNOTES_LOG) << "setDisplayDefaultValue slotNoteSaved(KJob*)";
 #endif
@@ -165,7 +146,7 @@ void KNote::saveNote(bool force, bool sync)
         return;
     }
     bool needToSave = false;
-    NoteShared::NoteDisplayAttribute *attribute
+    auto *attribute
         = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     const QPoint notePosition = pos();
     if (attribute->position() != notePosition) {
@@ -198,7 +179,7 @@ void KNote::saveNote(bool force, bool sync)
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << "save Note slotClose() slotNoteSaved(KJob*) : sync" << sync;
 #endif
-        Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+        auto *job = new Akonadi::ItemModifyJob(mItem);
         if (sync) {
             job->exec();
         } else {
@@ -299,7 +280,7 @@ void KNote::slotUpdateReadOnly()
     }
     if (!mBlockSave) {
         updateAllAttributes();
-        Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+        auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << " void KNote::slotUpdateReadOnly() slotNoteSaved(KJob*)";
 #endif
@@ -339,9 +320,9 @@ void KNote::slotUpdateReadOnly()
 
 void KNote::updateAllAttributes()
 {
-#if KDEPIM_HAVE_X11
-    NoteShared::NoteDisplayAttribute *attribute
+    auto *attribute
         = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+#if KDEPIM_HAVE_X11
     KWindowInfo info(winId(), NET::WMDesktop);
     const int count = KWindowSystem::numberOfDesktops();
     for (int n = 1; n <= count; ++n) {
@@ -363,7 +344,7 @@ void KNote::slotClose()
 {
     updateAllAttributes();
     m_editor->clearFocus();
-    Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+    auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
     qCDebug(KNOTES_LOG) << "slotClose() slotNoteSaved(KJob*)";
 #endif
@@ -381,7 +362,7 @@ void KNote::slotSetAlarm()
         bool needToModify = true;
         QDateTime dateTime = dlg->alarm();
         if (dateTime.isValid()) {
-            NoteShared::NoteAlarmAttribute *attribute
+            auto *attribute
                 = mItem.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
             attribute->setDateTime(dateTime);
         } else {
@@ -394,7 +375,7 @@ void KNote::slotSetAlarm()
         if (needToModify) {
             //Verify it!
             saveNoteContent();
-            Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+            auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
             qCDebug(KNOTES_LOG) << "setAlarm() slotNoteSaved(KJob*)";
 #endif
@@ -415,7 +396,7 @@ void KNote::saveNoteContent()
     message->date(true)->setDateTime(QDateTime::currentDateTime());
     message->mainBodyPart()->fromUnicodeString(text().isEmpty() ? QStringLiteral(" ") : text());
 
-    KMime::Headers::Generic *header = new KMime::Headers::Generic("X-Cursor-Position");
+    auto *header = new KMime::Headers::Generic("X-Cursor-Position");
     header->fromUnicodeString(QString::number(m_editor->cursorPositionFromStart()), "utf-8");
     message->setHeader(header);
 
@@ -428,7 +409,7 @@ void KNote::slotPreferences()
 {
     // create a new preferences dialog...
     QPointer<KNoteSimpleConfigDialog> dialog = new KNoteSimpleConfigDialog(name(), this);
-    NoteShared::NoteDisplayAttribute *attribute
+    auto *attribute
         = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     attribute->setSize(QSize(width(), height()));
 
@@ -439,7 +420,7 @@ void KNote::slotPreferences()
         dialog->save(mItem, isRichText);
         m_editor->setAcceptRichText(isRichText);
         saveNoteContent();
-        Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+        auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << "slotPreference slotNoteSaved(KJob*)";
 #endif
@@ -587,9 +568,9 @@ void KNote::updateKeepAboveBelow(bool save)
 #if KDEPIM_HAVE_X11
     NET::States state = KWindowInfo(winId(), NET::WMState).state();
 #else
-    NET::States state = 0; // neutral state, TODO
+    NET::States state = {}; // neutral state, TODO
 #endif
-    NoteShared::NoteDisplayAttribute *attribute
+    auto *attribute
         = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     if (m_keepAbove->isChecked()) {
         attribute->setKeepAbove(true);
@@ -607,7 +588,7 @@ void KNote::updateKeepAboveBelow(bool save)
     }
     if (!mBlockSave && save) {
         saveNoteContent();
-        Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+        auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << "slotUpdateKeepAboveBelow slotNoteSaved(KJob*)";
 #endif
@@ -629,6 +610,7 @@ void KNote::slotUpdateShowInTaskbar()
 
 void KNote::slotUpdateDesktopActions()
 {
+#if KDEPIM_HAVE_X11
     m_toDesktop->clear();
 
     QAction *act = m_toDesktop->addAction(i18n("&All Desktops"));
@@ -638,7 +620,7 @@ void KNote::slotUpdateDesktopActions()
         act->setChecked(true);
         act->setData(NETWinInfo::OnAllDesktops);
     }
-    QAction *separator = new QAction(m_toDesktop);
+    auto *separator = new QAction(m_toDesktop);
     separator->setSeparator(true);
     m_toDesktop->addAction(separator);
     const int count = KWindowSystem::numberOfDesktops();
@@ -650,6 +632,7 @@ void KNote::slotUpdateDesktopActions()
             desktopAct->setChecked(true);
         }
     }
+#endif
 }
 
 // -------------------- private methods -------------------- //
@@ -775,7 +758,7 @@ void KNote::createNoteHeader()
         }
     }
 
-    QBoxLayout *headerLayout = new QBoxLayout(headerLayoutDirection);
+    auto *headerLayout = new QBoxLayout(headerLayoutDirection);
 
     // create header label
     m_label = new QLabel(this);
@@ -820,7 +803,7 @@ void KNote::createNoteFooter()
     }
 
     // create size grip
-    QHBoxLayout *gripLayout = new QHBoxLayout;
+    auto *gripLayout = new QHBoxLayout;
     m_grip = new QSizeGrip(this);
     m_grip->setFixedSize(m_grip->sizeHint());
 
@@ -1081,12 +1064,12 @@ void KNote::showEvent(QShowEvent *)
         slotUpdateShowInTaskbar();
         toDesktop(mDisplayAttribute->desktop());
         move(mDisplayAttribute->position());
-        NoteShared::NoteDisplayAttribute *attr
+        auto *attr
             = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
         saveNoteContent();
         attr->setIsHidden(false);
         if (!mBlockSave) {
-            Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+            auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
             qCDebug(KNOTES_LOG) << "showEvent slotNoteSaved(KJob*)";
 #endif
@@ -1127,11 +1110,11 @@ void KNote::dropEvent(QDropEvent *e)
     if (md->hasColor()) {
         const QColor bg = qvariant_cast<QColor>(md->colorData());
 
-        NoteShared::NoteDisplayAttribute *attr
+        auto *attr
             = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
         saveNoteContent();
         attr->setBackgroundColor(bg);
-        Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
+        auto *job = new Akonadi::ItemModifyJob(mItem);
 #ifdef DEBUG_SAVE_NOTE
         qCDebug(KNOTES_LOG) << "dropEvent slotNoteSaved(KJob*)";
 #endif
@@ -1164,7 +1147,7 @@ bool KNote::eventFilter(QObject *o, QEvent *ev)
     }
 
     if (o == m_label) {
-        QMouseEvent *e = (QMouseEvent *)ev;
+        auto *e = (QMouseEvent *)ev;
 
         if (ev->type() == QEvent::MouseButtonDblClick) {
             if (!m_editor->isReadOnly()) {
@@ -1173,23 +1156,23 @@ bool KNote::eventFilter(QObject *o, QEvent *ev)
         }
 
         if (ev->type() == QEvent::MouseButtonPress
-            && (   (e->buttons() & Qt::LeftButton) == Qt::LeftButton
-                || (e->buttons() & Qt::MiddleButton)  == Qt::MiddleButton)) {
+            && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton
+                || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
             mOrigPos = e->pos();
             return false;
         }
 
         if (ev->type() == QEvent::MouseMove
-            && (   (e->buttons() & Qt::LeftButton) == Qt::LeftButton
-                || (e->buttons() & Qt::MiddleButton)  == Qt::MiddleButton)) {
+            && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton
+                || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
             QPoint newPos = e->globalPos() - mOrigPos - QPoint(1, 1);
             move(newPos);
             return true;
         }
 
         if (ev->type() == QEvent::MouseButtonRelease
-            && (   (e->buttons() & Qt::LeftButton) == Qt::LeftButton
-                || (e->buttons() & Qt::MiddleButton)  == Qt::MiddleButton)) {
+            && ((e->buttons() & Qt::LeftButton) == Qt::LeftButton
+                || (e->buttons() & Qt::MiddleButton) == Qt::MiddleButton)) {
             QPoint newPos = e->globalPos() - mOrigPos - QPoint(1, 1);
             move(newPos);
             return false;
@@ -1199,7 +1182,7 @@ bool KNote::eventFilter(QObject *o, QEvent *ev)
 
     if (o == m_editor) {
         if (ev->type() == QEvent::FocusOut) {
-            QFocusEvent *fe = static_cast<QFocusEvent *>(ev);
+            auto *fe = static_cast<QFocusEvent *>(ev);
             if (fe->reason() != Qt::PopupFocusReason && fe->reason() != Qt::MouseFocusReason) {
                 updateFocus();
                 if (!mBlockSave) {
